@@ -20,7 +20,6 @@ sub DESCRIPTION {
 sub new {
 	my $class=shift;
 	my $this=$class->SUPER::new(@_);
-	$this->{phppkginfo_path} = '/usr/share/pkg-php-tools/scripts/phppkginfo';
 	$this->{pkgtools_cmd} = ['/usr/bin/pkgtools'];
 	# Out of source tree building is prefered.
 	$this->prefer_out_of_source_building(@_);
@@ -30,7 +29,6 @@ sub new {
 sub testmode {
 	my $this=shift;
 	my $sourcedir=shift;
-	$this->{phppkginfo_path} = File::Spec->catfile($sourcedir, 'share/pkg-php-tools/scripts/phppkginfo');
 	$this->{pkgtools_cmd} = ['/usr/bin/php',
 		'-d', "include_path=$sourcedir/share/php",
 		"$sourcedir/bin/pkgtools"];
@@ -280,7 +278,7 @@ sub install {
 			if (-e $this->get_sourcepath("package2.xml")) {
 				$this->doit_in_sourcedir("cp", "package2.xml", $destdir."/usr/share/doc/".$this->_get_mainpackage());
 			}
-			complex_doit($this->{phppkginfo_path}." -d changelog ".$this->get_sourcedir()." > ".$destdir."/usr/share/doc/".$this->_get_mainpackage()."/changelog");
+			complex_doit(join(' ', @{$this->{pkgtools_cmd}})." --sourcedirectory ".$this->get_sourcedir()." phppear changelog > ".$destdir."/usr/share/doc/".$this->_get_mainpackage()."/changelog");
 		}
 	}
 	if (-e $this->get_sourcepath("channel.xml")) {
