@@ -33,20 +33,16 @@
 * @license Expat http://www.jclark.com/xml/copying.txt
 */
 class PhpcomposerSourceTest extends PHPUnit\Framework\TestCase {
-    /**
-     * @expectedException InvalidArgumentException
-     * @expectedExceptionMessage composer.json not found
-     */
     public function testFailedOpen() {
+        $this->expectException('InvalidArgumentException');
+        $this->expectExceptionMessage('composer.json not found');
         // Open a directory without a composer.json
         $source = new \Pkgtools\Phpcomposer\Source('testsuite/data');
     }
 
-    /**
-     * @expectedException InvalidArgumentException
-     * @expectedExceptionMessage Error parsing composer.json: Syntax error, malformed JSON (Syntax error)
-     */
     public function testBrokenOpen() {
+        $this->expectException('InvalidArgumentException');
+        $this->expectExceptionMessage('Error parsing composer.json: Syntax error, malformed JSON (Syntax error)');
         // Open a directory with a broken composer.json
         $source = new \Pkgtools\Phpcomposer\Source('testsuite/data/broken');
     }
