@@ -32,12 +32,10 @@
 * @author Mathieu Parent <sathieu@debian.org>
 * @license Expat http://www.jclark.com/xml/copying.txt
 */
-class PhppearSourceTest extends PHPUnit_Framework_TestCase {
-    /**
-     * @expectedException InvalidArgumentException
-     * @expectedExceptionMessage package.xml not found
-     */
+class PhppearSourceTest extends PHPUnit\Framework\TestCase {
     public function testFailedOpen() {
+        $this->expectException('InvalidArgumentException');
+        $this->expectExceptionMessage('package.xml not found');
         // Open a directory without a package.xml
         $source = new \Pkgtools\Phppear\Source('testsuite/data');
     }
@@ -75,7 +73,14 @@ class PhppearSourceTest extends PHPUnit_Framework_TestCase {
      * @depends testOpen
      */
     public function testDescription($source) {
-        $this->assertEquals('<Some random notes>', $source->description);
+        $this->assertEquals('<Some random notes>
+    This is a paragraph.
+
+    Those are bullets:
+    * Number one
+    * Number two
+ ',
+            $source->description);
     }
 
     /**
